# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [v0.8.0] - 2026-02-11
### Added
- Add SiLA multi client behavior [f63e6976d](https://gitlab.com/unitelabs/cdk/python-cdk/commit/f63e6976d0cce6bbee87839f55935890e0b08477) (INT-8)

### Fixed
- allow pending connector startup to be gracefully cancelled [1c98bc86e](https://gitlab.com/unitelabs/cdk/python-cdk/commit/1c98bc86efed2cd6fbb8508c65a17f08a4c15907) (INT-54)
- update to latest 0.7.1 sila pythin lib to fix the feature identifier namespace error [4cb8b34cb](https://gitlab.com/unitelabs/cdk/python-cdk/commit/4cb8b34cb7a855909ca03f0ccce00e5a3175003a)

### Removed
- `ObservableCommand.__init__(display_name)`: *Parameter was removed*

## [V0.7.2] - 2026-01-29
### Added
- `sync(title)`: *Parameter was added as required*
- `push_to_gitlab(title)`: *Parameter was added as required*

### Changed
- `DEFAULT_BRANCH`: *Attribute value was changed*: `'chore/cruft-update'` -> `'feature/cruft-update'`

### Fixed
- release glab installation and revert back to previous license and readme [c3fb15182](https://gitlab.com/unitelabs/cdk/python-cdk/commit/c3fb151824afa57e9386c89d8dad90e80e9eeb67) (INT-19)

## [V0.7.1] - 2026-01-26
### Fixed
- Fix root certificate config to load paths from the file system [8745a005c](https://gitlab.com/unitelabs/cdk/python-cdk/commit/8745a005cc3cec25f56d99e1adcce0e96f1e4d44) (INT-22)

[Unreleased]: https://gitlab.com/unitelabs/cdk/python-cdk/compare/v0.8.0...HEAD
[v0.8.0]: https://gitlab.com/unitelabs/cdk/python-cdk/compare/v0.7.2...v0.8.0
[V0.7.2]: https://gitlab.com/unitelabs/cdk/python-cdk/compare/v0.7.1...v0.7.2
[V0.7.1]: https://gitlab.com/unitelabs/cdk/python-cdk/compare/v0.7.0...v0.7.1
